@@ -9,11 +9,11 @@ runtime_summary_condensed <- reactive({
   df$funcId %<>% as.integer
   df$DIM %<>% as.integer
   df$succ %<>% as.integer
-  df$"worst recorded" <- format_FV(df$"worst recorded") %>% as.numeric
-  df$"worst reached" <- format_FV(df$"worst reached") %>% as.numeric
-  df$"mean reached" <- format_FV(df$"mean reached") %>% as.numeric
-  df$"median reached" <- format_FV(df$"median reached") %>% as.numeric
-  df$"best reached" <- format_FV(df$"best reached") %>% as.numeric
+  df$"worst recorded" <- format_FV(df$"worst recorded")
+  df$"worst reached" <- format_FV(df$"worst reached")
+  df$"mean reached" <- format_FV(df$"mean reached")
+  df$"median reached" <- format_FV(df$"median reached")
+  df$"best reached" <- format_FV(df$"best reached")
   df
 })
 
@@ -30,11 +30,7 @@ output$RTSummary.Overview.Download <- downloadHandler(
   content = function(file) {
     df <- runtime_summary_condensed()
     df <- df[input[["table_RT_overview_rows_all"]]]
-    if (input$RTSummary.Overview.Format == 'csv')
-      write.csv(df, file, row.names = F)
-    else{
-      print(xtable(df), file = file)
-    }
+    save_table(df, file)
   }
 )
 
@@ -44,9 +40,9 @@ runtime_summary <- reactive({
       input$RTSummary.Statistics.Max,
       input$RTSummary.Statistics.Step)
 
-  fstart <- format_FV(input$RTSummary.Statistics.Min) %>% as.numeric
-  fstop <- format_FV(input$RTSummary.Statistics.Max) %>% as.numeric
-  fstep <- format_FV(input$RTSummary.Statistics.Step) %>% as.numeric
+  fstart <- format_FV(input$RTSummary.Statistics.Min)
+  fstop <- format_FV(input$RTSummary.Statistics.Max)
+  fstep <- format_FV(input$RTSummary.Statistics.Step)
   data <- DATA()
   
   if (!input$RTSummary.Statistics.Single) {
@@ -73,8 +69,7 @@ runtime_summary <- reactive({
   df$ERT <- round(df$ERT, digits = 2)
   df$ps <- round(df$ps, digits = 2)
 
-  if (format == COCO)
-    df$target <- formatC(df$target, format = "e", digits = 2)
+  df$target <- format_FV(df$target)
   df
 })
 
@@ -90,11 +85,7 @@ output$RTSummary.Statistics.Download <- downloadHandler(
   content = function(file) {
     df <- runtime_summary()
     df <- df[input[["table_RT_summary_rows_all"]]]
-    if (input$RTSummary.Statistics.Format == 'csv')
-      write.csv(df, file, row.names = F)
-    else{
-      print(xtable(df), file = file)
-    }
+    save_table(df, file)
   }
 )
 
@@ -103,12 +94,12 @@ get_RT <- reactive({
       input$RTSummary.Sample.Max,
       input$RTSummary.Sample.Step)
 
-  fstart <- format_FV(input$RTSummary.Sample.Min) %>% as.numeric
-  fstop <- format_FV(input$RTSummary.Sample.Max) %>% as.numeric
-  fstep <- format_FV(input$RTSummary.Sample.Step) %>% as.numeric
+  fstart <- format_FV(input$RTSummary.Sample.Min)
+  fstop <- format_FV(input$RTSummary.Sample.Max)
+  fstep <- format_FV(input$RTSummary.Sample.Step)
   data <- DATA()
 
-  if (!input$RTSummary.Sample.Single){
+  if (!input$RTSummary.Sample.Single) {
     req(fstart <= fstop, fstep <= fstop - fstart, length(data) > 0)
     fall <- get_funvals(data)
     fseq <- seq_FV(fall, fstart, fstop, fstep)
@@ -120,8 +111,7 @@ get_RT <- reactive({
 
   df <- get_RT_sample(data, ftarget = fseq, algorithm = input$RTSummary.Sample.Algid,
                 output = input$RTSummary.Sample.DownloadFormat)
-  if (format == COCO)
-    df$target <- formatC(df$target, format = "e", digits = 2)
+  df$target <- format_FV(df$target)
   df[is.na(df)] <- 'NA'
   df
 })
@@ -133,10 +123,7 @@ output$RTSummary.Sample.Download <- downloadHandler(
   content = function(file) {
     df <- get_RT()
     df <- df[input[["table_RT_sample_rows_all"]]]
-    if (input$RTSummary.Sample.Format == 'csv')
-      write.csv(df, file, row.names = F)
-    else
-      print(xtable(df), file = file)
+    save_table(df, file)
     }
 )
 
