@@ -159,17 +159,13 @@ options = list(dom = 'lrtip', pageLength = 15, scrollX = T, server = T, digits =
 
 output$RT_PAR.Sample.Download <- downloadHandler(
   filename = function() {
-    eval(PARSample_csv_name)
+    eval(RT_PARSample_csv_name)
   },
   content = function(file) {
     df <- parameter_sample()
     df <- df[input[["table_RT_PAR_SAMPLE_rows_all"]]]
-    if (input$RT_PAR.Sample.FileFormat == 'csv')
-      write.csv(df, file, row.names = F)
-    else
-      print(xtable(df), file = file)
-  },
-  contentType = "text/csv"
+    save_table(df, file)
+  }
 )
 
 output$RT_PAR.Summary.Download <- downloadHandler(
@@ -179,10 +175,6 @@ output$RT_PAR.Summary.Download <- downloadHandler(
   content = function(file) {
     df <- rt_parameter_summary()
     df <- df[input[["table_RT_PAR_summary_rows_all"]]]
-    if (input$RT_PAR.Summary.Format == 'csv')
-      write.csv(df, file, row.names = F)
-    else
-      print(xtable(df), file = file)
-  },
-  contentType = "text/csv"
+    save_table(df, file)
+  }
 )
\ No newline at end of file
