@@ -48,7 +48,7 @@ rt_par_expected_value_box <- function(width = 12, collapsible = T, collapsed = T
       
       hr(),
       selectInput('RT_PAR.Plot.Format', label = 'Select the figure format',
-                  choices = supported_fig_format, selected = 'pdf'),
+                  choices = supported_fig_format, selected = supported_fig_format[[1]]),
       downloadButton('RT_PAR.Plot.Download', label = 'Download the figure')
     ),
     
@@ -85,7 +85,7 @@ rt_par_summary_box <- function(width = 12, collapsible = T, collapsed = T) {
       selectInput('RT_PAR.Summary.Algid', 'Algorithms', choices = NULL, selected = NULL),
       selectInput('RT_PAR.Summary.Param', 'Parameters', choices = NULL, selected = NULL),
       hr(),
-      selectInput('RT_PAR.Summary.Format', 'Format', choices = c('csv','tex'), selected = 'csv'),
+      selectInput('RT_PAR.Summary.Format', 'Format', choices = supported_table_format, selected = supported_table_format[[1]]),
       downloadButton("RT_PAR.Summary.Download", "Save this table as csv")
     ),
     
@@ -119,7 +119,7 @@ rt_par_sample_box <- function(width = 12, collapsible = T, collapsed = T) {
       hr(),
       selectInput('RT_PAR.Sample.Format', 'Format of the table',
                   choices = c('long', 'wide'), selected = 'wide'),
-      selectInput('RT_PAR.Sample.FileFormat', 'File-Format', choices = c('csv','tex'), selected = 'csv'),
+      selectInput('RT_PAR.Sample.FileFormat', 'File-Format', choices = supported_table_format, selected = supported_table_format[[1]]),
       downloadButton("RT_PAR.Sample.Download", "Save this table")
     ),
     
