@@ -12,7 +12,18 @@ F_MIN_LABEL <- HTML('<p>\\(f_{\\text{min}}:\\) Smallest target value</p>')
 F_MAX_LABEL <- HTML('<p>\\(f_{\\text{max}}:\\) Largest target value</p>')
 F_STEP_LABEL <- HTML('<p>\\(\\Delta f:\\) Granularity (step size)</p>')
 
-header <- dashboardHeader(title = HTML('<div align="center"><b>IOHanalyzer</b></div>'))
+Pdsc_info <- "Practical Deep Comparison uses this 
+                as a threshold parameter to determine when two performance measure values are 
+                equal or different from a practical point of view.
+                Since the practical significance 
+                is handled with preprocessing using the predefined threshold in sequential order of 
+                the obtained runs, to make more robust analysis a Monte-Carlo simulation is required."
+
+Pdsc_mc_info <- "Practical Deep Comparison uses this 
+                to determine the number of monte-carlo simulations to perform. 
+                The Monte-Carlo simulation involves preprocessing done with different orders of the 
+                independent runs before comparing the distribution of the data.
+                This only has effect if threshold for practical significance > 0"
 
 HTML_P <- function(s) HTML(paste0('<p align="left" style="font-size:120%;">', s, '</p>'))
 
